Rename StorageClass to AddressSpace.

This CL updates the internals to use AddressSpace instead of the old
StorageClass name.

Bug: tint:1404
Change-Id: Iecc208e839453437f4d630f65e0152206a52db7e
Reviewed-on: https://dawn-review.googlesource.com/c/dawn/+/104420
Reviewed-by: Ben Clayton <bclayton@google.com>
Commit-Queue: Dan Sinclair <dsinclair@chromium.org>
Auto-Submit: Dan Sinclair <dsinclair@chromium.org>
diff --git a/src/tint/transform/decompose_memory_access.h b/src/tint/transform/decompose_memory_access.h
index 1d95dc4..2e92a3a 100644
--- a/src/tint/transform/decompose_memory_access.h
+++ b/src/tint/transform/decompose_memory_access.h
@@ -75,9 +75,9 @@
         /// @param pid the identifier of the program that owns this node
         /// @param nid the unique node identifier
         /// @param o the op of the intrinsic
         /// @param sc the storage class of the buffer
         /// @param ty the data type of the intrinsic
-        Intrinsic(ProgramID pid, ast::NodeID nid, Op o, ast::StorageClass sc, DataType ty);
+        Intrinsic(ProgramID pid, ast::NodeID nid, Op o, ast::AddressSpace sc, DataType ty);
         /// Destructor
         ~Intrinsic() override;
 
@@ -96,8 +96,8 @@
         /// The op of the intrinsic
         const Op op;
 
-        /// The storage class of the buffer this intrinsic operates on
-        ast::StorageClass const storage_class;
+        /// The address space of the buffer this intrinsic operates on
+        ast::AddressSpace const address_space;
 
         /// The type of the intrinsic
         const DataType type;
@@ -75,9 +75,9 @@
         /// @param nid the unique node identifier
         /// @param o the op of the intrinsic
-        /// @param sc the storage class of the buffer
+        /// @param sc the address space of the buffer
         /// @param ty the data type of the intrinsic